//====================================================================
//== Course:     Chemical Plants II                                 ==
//==             Laboratory no.7                                    ==
//== Title:      Cooling tower								        ==
//== Solution:   ODE System solving						            ==
//==             Using BzzMath                                      ==
//== Author:     Alessandro Di Pretoro (SuPER,POLIMI)               ==
//==             alessandro.dipretoro@polimi.it                     ==
//==             www.super.chem.polimi.it/ing-alessandro-di-pretoro ==
//== Date:       2018.12.12                                         ==
//==                                                                ==				*
//	==================================================================


#define BZZ_COMPILER 3
#include <BzzMath.hpp>

void Coolingtower(BzzVector &y, double z, BzzVector &dy);
FILE *res;
//DATA
double Lin = 20000;								// kg/h
double Gdry = 15000;							// kg/h
double P = 760;									// mmHg
double TinH2O = 50;								// C
double ToutH2O = 25;							// C
double Tinair = 20;								// C
double Z = 0.5;									// relative humidity
double Cu = 0.26;								// kcal/kg*K
double CpL = 1;									// kcal/kg*K	
double DHev = 580;								// kcal/kg
double hga = 4000;								// kcal/m/h/K
double hla = 30000;								// kcal/m/h/K
double A = -49.705;								// Pev 1st coeff	mmHg vs C
double B = 2.71;								// Pev 2nd coeff    mmHg vs C
double Usair = 0.62*(A + B*Tinair) / P;
double Uair = Z*Usair;
double Kua = hga / Cu;
double L0 = 19292;								// kg/h

void main(void)
{

	double height = 0.;
	double delta = 1.;
	res = fopen("Res.ris", "w");
	BzzVector y0(5, Uair, ToutH2O, Tinair, L0, Gdry);
	printf("\nINITIAL CONDITIONS:\tU = %e\tTl = %e\tTg = %e\tL = %e\tG = %e", y0[1], y0[2], y0[3], y0[4], y0[5]);
	BzzVector y, dy;
	BzzOdeNonStiff o(y0, height, Coolingtower);
	y = y0;
	for (int i = 0; i <= 1000; i++)
	{
		height = double(i);
		printf("\nHEIGHT=%d\tU = %e\tTl = %e\tTg = %e\tL = %e\tG = %e", i, y[1], y[2], y[3], y[4], y[5]);
		fprintf(res, "\n%e\t%e\t%e\t%e\t%e\t%e", height, y[1], y[2], y[3], y[4], y[5]);
		o.SetInitialConditions(y, height);
		y = o(height + delta);
	}
	fclose(res);
}

void Coolingtower(BzzVector &y, double z, BzzVector &dy)
{
	// U Tl Tg L G

	double Ti = (hla*y[2] + hga*y[3] + Kua*DHev*(y[1] - 0.62*A / P)) / (hla + hga + Kua*DHev*0.62*B / P);
	double Ui = 0.62*(A + B*Ti) / P;

	dy[1] = Kua*(Ui - y[1]) / Gdry / 100;
	dy[2] = hla*(y[2] - Ti) / y[4] / CpL / 100;
	dy[3] = hga*(Ti - y[3]) / Gdry / Cu / 100;
	dy[4] = Kua*(Ui - y[1]) / 100;
	dy[5] = Kua*(Ui - y[1]) / 100;

}